@@ -4,11 +4,11 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-from weather_provider_api.routers.weather.sources.knmi.client.arome_repository import AromeRepository
+from weather_provider_api.routers.weather.sources.knmi.client.arome_repository import HarmonieAromeRepository
 
 
 def main():
-    arome_repo = AromeRepository()
+    arome_repo = HarmonieAromeRepository()
     arome_repo.purge_repository()
 
 
